# Reamber (Py)

**Status: Development Halted for studies**

**Requires Python >=3.7**

`pip install reamber`

This is a simple package to handle VSRG file, useful if you'd want to manipulate data
such as offset, column, bpm, etc.

This doesn't provide complex algorithms, only the base dataclasses and helpful basic
algorithms

# For Developers

Note that reamber is still in alpha stage, means a lot of things aren't settled down
yet. That means that a lot of function names and references will change without notice.

It is recommended to only build scratch/temp files if you want to utilize this library

# Wiki

[Visit the wiki for more info](https://eve-ning.github.io/reamberPy/index.html)

[Getting Started](https://eve-ning.github.io/reamberPy/info/gettingStarted.html)

# Motivation

A growing amount of osu!mania players are becoming interested in programming.
The best way to learn is to relate it to something that you're familiar with.
That's why I'm making a library for most common VSRG (Vertical Scrolling Rhythm Game)
types.
